@@ -38,6 +38,12 @@ def make_parser():
         help="Use a custom config snippet file to override specific config options",
     )
 
+    parser.add_argument(
+        "--no-update",
+        action="store_true",
+        help="Skip if the config file already exists",
+    )
+
     g = parser.add_argument_group(title="Mode").add_mutually_exclusive_group()
 
     g.add_argument(
@@ -276,12 +282,13 @@ def do_it():
     linuxname = shlex.quote(arch.linuxname)
     archargs = [f"ARCH={linuxname}"]
 
-    if shutil.which(f"{arch.gccname}-linux-gnu-gcc"):
+    if shutil.which(f"{arch.gccname}-linux-gnu-gcc") and arch.gccname != uname.machine:
         gccname = shlex.quote(f"{arch.gccname}-linux-gnu-")
         archargs.append(f"CROSS_COMPILE={gccname}")
 
     maketarget: Optional[str]
 
+    updatetarget = ""
     if args.allnoconfig:
         maketarget = "allnoconfig"
         updatetarget = "syncconfig"
@@ -289,6 +296,8 @@ def do_it():
         maketarget = arch.defconfig_target
         updatetarget = "olddefconfig"
     elif args.update:
+        if args.no_update:
+            arg_fail("--update and --no-update cannot be used together")
         maketarget = None
         updatetarget = "olddefconfig"
     else:
@@ -306,18 +315,24 @@ def do_it():
     if config_dir and os.path.isdir(config_dir):
         config = os.path.join(config_dir, config)
 
-    if not os.path.exists(config):
-        # Set up an initial config
-        if maketarget is None:
-            maketarget = arch.defconfig_target
+    if os.path.exists(config):
+        if args.no_update:
+            print(f"{config} file exists: no modifications have been done")
+            return 0
+    else:
+        if args.update:
+            print(f"Error: {config} file is missing")
+            return 1
+
+    if maketarget is not None:
         try:
             subprocess.check_call(["make"] + archargs + [maketarget])
         except Exception as exc:
             raise SilentError() from exc
 
-        # Append virtme configs
-        with open(config, "ab") as conffile:
-            conffile.write("\n".join(conf).encode("utf-8"))
+    # Append virtme configs
+    with open(config, "ab") as conffile:
+        conffile.write("\n".join(conf).encode("utf-8"))
 
     # Run the update target
     try:
