@@ -157,7 +157,7 @@ def make_parser():
         "--kconfig",
         "-k",
         action="store_true",
-        help="Only generate the kernel .config without building/running anything",
+        help="Only override the kernel .config without building/running anything",
     )
 
     parser.add_argument(
@@ -311,8 +311,8 @@ def make_parser():
     parser.add_argument(
         "--network",
         "-n",
-        action="store",
-        metavar="user|bridge",
+        action="append",
+        choices=['user', 'bridge', 'loop'],
         help="Enable network access",
     )
 
@@ -408,7 +408,8 @@ def make_parser():
         "--force",
         action="store_true",
         help="Force reset git repository to target branch or commit "
-        "(warning: this may drop uncommitted changes)",
+        "(warning: this may drop uncommitted changes), "
+        "and force kernel config override",
     )
 
     parser.add_argument(
@@ -565,7 +566,9 @@ class KernelSource:
     def config(self, args):
         """Perform a make config operation on a kernel source directory."""
         arch = args.arch
-        cmd = "virtme-configkernel --update"
+        cmd = "virtme-configkernel --defconfig"
+        if not args.force and not args.kconfig:
+            cmd += " --no-update"
         if arch is not None:
             if arch not in ARCH_MAPPING:
                 arg_fail(f"unsupported architecture: {arch}")
@@ -842,7 +845,8 @@ class KernelSource:
 
     def _get_virtme_network(self, args):
         if args.network is not None:
-            self.virtme_param["network"] = f"--net {args.network}"
+            network_str = " ".join([f"--net {network}" for network in args.network])
+            self.virtme_param["network"] = network_str
         else:
             self.virtme_param["network"] = ""
 
